# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from .x_relative_text_content_insert import XRelativeTextContentInsert as XRelativeTextContentInsert_7dca1156
from .x_text import XText as XText_690408ca
from .x_text_range_compare import XTextRangeCompare as XTextRangeCompare_f04e0d7e
from .x_text_range_mover import XTextRangeMover as XTextRangeMover_d5ff0cc0
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6

class Text(XEnumerationAccess_4bac0ffc, XRelativeTextContentInsert_7dca1156, XText_690408ca, XTextRangeCompare_f04e0d7e, XTextRangeMover_d5ff0cc0):
    """
    Service Class

    is an independent piece of text which consists of a series of one or more paragraphs.
    
    This service is used, for example, for the text of a TextDocument or the text in a cell or TextFrame.

    See Also:
        `API Text <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1Text.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.Text'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def EndRedline(self) -> PropertyValues_d6470ce6:
        """
        contains the properties of a redline at the start of the document.
        
        The sequence contains the following properties
        """
        ...

    @abstractproperty
    def StartRedline(self) -> PropertyValues_d6470ce6:
        """
        contains the properties of a redline at the start of the document.
        
        The sequence contains the following properties
        """
        ...


__all__ = ['Text']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..sdbc.sql_warning import SQLWarning as SQLWarning_96f10a6a
from ..uno.x_interface import XInterface as XInterface_8f010a43

class SQLContext(SQLWarning_96f10a6a):
    """
    Exception Class

    provides special information about the context where a com.sun.star.sdbc.SQLException occurred.
    
    As usual for SQLExceptions, several SQLContext-objects may be chained, then the most recent context is appended to the list's tail.

    See Also:
        `API SQLContext <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.SQLContext'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.sdb.SQLContext'
    __pyunostruct__: str = 'com.sun.star.sdb.SQLContext'

    typeName: str = 'com.sun.star.sdb.SQLContext'
    """Literal Constant ``com.sun.star.sdb.SQLContext``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, SQLState: typing.Optional[str] = '', ErrorCode: typing.Optional[int] = 0, NextException: typing.Optional[object] = None, Details: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            SQLState (str, optional): SQLState value.
            ErrorCode (int, optional): ErrorCode value.
            NextException (object, optional): NextException value.
            Details (str, optional): Details value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "SQLState": SQLState,
            "ErrorCode": ErrorCode,
            "NextException": NextException,
            "Details": Details,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._details = kwargs["Details"]
        inst_keys = ('Details',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Details(self) -> str:
        """
        provides special info about the details where a com.sun.star.sdbc.SQLException occurred.
        
        As usual for SQLExceptions, several SQLContext-objects may be chained, then the most recent context is appended to the list's tail
        """
        return self._details
    
    @Details.setter
    def Details(self, value: str) -> None:
        self._details = value


__all__ = ['SQLContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_drag_gesture_listener import XDragGestureListener as XDragGestureListener_e8b41366

class XDragGestureRecognizer(XInterface_8f010a43):
    """
    This interface is implemented by a view or window that supports drag operations.
    
    Different to Java, the association between view and interface is fixed and cannot be changed. Otherwise, the AWT messaging would have to be implemented for any window supporting Drag and Drop operations, which would be a performance issue.

    See Also:
        `API XDragGestureRecognizer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragGestureRecognizer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XDragGestureRecognizer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XDragGestureRecognizer'

    @abstractmethod
    def addDragGestureListener(self, dgl: XDragGestureListener_e8b41366) -> None:
        """
        Registers a new XDragGestureListener.
        """
        ...
    @abstractmethod
    def removeDragGestureListener(self, dgl: XDragGestureListener_e8b41366) -> None:
        """
        Unregisters the specified XDragGestureListener.
        """
        ...
    @abstractmethod
    def resetRecognizer(self) -> None:
        """
        Reset the recognizer.
        
        If it is currently recognizing a gesture, ignore it.
        """
        ...

__all__ = ['XDragGestureRecognizer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
from .x_uri_reference_factory import XUriReferenceFactory as XUriReferenceFactory_a740e47

class UriReferenceFactory(XUriReferenceFactory_a740e47):
    """
    Service Class

    creates URI references.
    
    See RFC 3986 for a description of URI references and related terms.
    
    For parsing absolute URI references, this service tries to use a scheme-specific parser. Such a scheme-specific parser will typically enforce additional restrictions during parsing, and will typically return objects that support extra, scheme-specific interfaces in addition to com.sun.star.uri.XUriReference. If no such parser is found, and for relative URI references, a generic parser is used, which returns objects that only support com.sun.star.uri.XUriReference.
    
    Locating a scheme-specific parser works as follows: A scheme consists of Latin capital letters “A”–“Z”, Latin small letters “a”–“z”, digits “0”–“9”, “+”, “-”, and “.”. A scheme s is transformed into a string s′ character-by-character, by translating Latin capital letters to their small counterparts, translating “+” to “PLUS”, “-” to “HYPHEN”, “.” to “DOT”, and copying Latin small letters and digits unchanged. If the component context used while creating this UriReferenceFactory instance offers a service manager, and there is a service available at that service manager whose name is the concatenation of “com.sun.star.uri.UriSchemeParser_” and s′, then that service is used. It is an error if that service does not support com.sun.star.uri.XUriSchemeParser.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UriReferenceFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1uri_1_1UriReferenceFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.UriReferenceFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['UriReferenceFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form.binding
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ListEntryEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies the event which is notified when a change in a string entry list occurred

    See Also:
        `API ListEntryEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntryEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.ListEntryEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.form.binding.ListEntryEvent'
    """Literal Constant ``com.sun.star.form.binding.ListEntryEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Entries: typing.Optional[typing.Tuple[str, ...]] = (), Position: typing.Optional[int] = 0, Count: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Entries (typing.Tuple[str, ...], optional): Entries value.
            Position (int, optional): Position value.
            Count (int, optional): Count value.
        """

        if isinstance(Source, ListEntryEvent):
            oth: ListEntryEvent = Source
            self.Source = oth.Source
            self.Entries = oth.Entries
            self.Position = oth.Position
            self.Count = oth.Count
            return

        kargs = {
            "Source": Source,
            "Entries": Entries,
            "Position": Position,
            "Count": Count,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._entries = kwargs["Entries"]
        self._position = kwargs["Position"]
        self._count = kwargs["Count"]
        inst_keys = ('Entries', 'Position', 'Count')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Entries(self) -> typing.Tuple[str, ...]:
        """
        denotes the changed entries
        
        The concrete semantics of the value depends on the concrete event being notified.
        """
        return self._entries

    @Entries.setter
    def Entries(self, value: typing.Tuple[str, ...]) -> None:
        self._entries = value

    @property
    def Position(self) -> int:
        """
        denotes the position where a change occurred.
        
        The concrete semantics of the value depends on the concrete event being notified.
        """
        return self._position

    @Position.setter
    def Position(self, value: int) -> None:
        self._position = value

    @property
    def Count(self) -> int:
        """
        denotes the number of changed entries, in case a change of an entry range is being notified.
        """
        return self._count

    @Count.setter
    def Count(self, value: int) -> None:
        self._count = value


__all__ = ['ListEntryEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.style.HorizontalAlignment import HorizontalAlignmentProto

class HorizontalAlignment(Enum):
    """
    Enum Class


    See Also:
        `API HorizontalAlignment <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#aa00e70829e72ff16addc4d9f06fe3bc5>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.HorizontalAlignment'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.style.HorizontalAlignment'

    CENTER = cast("HorizontalAlignmentProto", 'CENTER')
    """
    set the horizontal alignment to the center between the margins from the container object
    
    The text range is centered between the previous tabulator (or the left border, if none) and this tabulator.
    
    adjusted to the center
    """
    LEFT = cast("HorizontalAlignmentProto", 'LEFT')
    """
    set the horizontal alignment to the left margin from the container object
    
    The text range is left-aligned between the previous tabulator (or the left border, if none) and this tabulator.
    
    adjusted to the left border
    
    The page style is only used for left pages.
    """
    RIGHT = cast("HorizontalAlignmentProto", 'RIGHT')
    """
    set the horizontal alignment to the right margin from the container object
    
    The text range is right-aligned between the previous tabulator (or the left border, if none) and this tabulator.
    
    adjusted to the right border
    
    The page style is only used for right pages.
    """

__all__ = ['HorizontalAlignment']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.chart2.TransparencyStyle import TransparencyStyleProto

class TransparencyStyle(Enum):
    """
    Enum Class

    ENUM TransparencyStyle

    See Also:
        `API TransparencyStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2.html#acc7ba74ba6531a134bb92607b8616cb6>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.TransparencyStyle'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.chart2.TransparencyStyle'

    GRADIENT = cast("TransparencyStyleProto", 'GRADIENT')
    """
    The property TransparencyGradient is evaluated, Transparency is ignored.
    """
    LINEAR = cast("TransparencyStyleProto", 'LINEAR')
    """
    The property Transparency is evaluated, TransparencyGradient is ignored.
    """
    NONE = cast("TransparencyStyleProto", 'NONE')
    """
    Default, no pies are exploded.
    
    no transparency attribute is evaluated
    
    The symbol is invisible.
    """

__all__ = ['TransparencyStyle']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class UnsupportedNameClashException(Exception_85530a09):
    """
    Exception Class

    This exception must be thrown in case the requested name clash directive is not supported, because it is not possible to implement it or if it is just not (yet) implemented.
    
    Command \"transfer\": Used if the name clash directive specified in parameter NameClash of the supplied TransferInfo is not supported. For example, if the NameClash was set to NameClash.ERROR, to NameClash.RENAME or to NameClash.ASK, the implementation must be able determine whether there are existing data. This exception must also be used if NameClash.RENAME was specified and the implementation is unable to create a valid new name after a suitable number of tries.
    
    Command \"insert\": Used if the parameter ReplaceExisting of the supplied InsertCommandArgument was set to FALSE and the implementation is unable to determine whether there are existing data. The member NameClash of the exception must be set to NameClash.ERROR

    See Also:
        `API UnsupportedNameClashException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedNameClashException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.UnsupportedNameClashException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.UnsupportedNameClashException'
    __pyunostruct__: str = 'com.sun.star.ucb.UnsupportedNameClashException'

    typeName: str = 'com.sun.star.ucb.UnsupportedNameClashException'
    """Literal Constant ``com.sun.star.ucb.UnsupportedNameClashException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, NameClash: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            NameClash (int, optional): NameClash value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "NameClash": NameClash,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name_clash = kwargs["NameClash"]
        inst_keys = ('NameClash',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def NameClash(self) -> int:
        """
        contains the NameClash that is not supported.
        """
        return self._name_clash
    
    @NameClash.setter
    def NameClash(self, value: int) -> None:
        self._name_clash = value


__all__ = ['UnsupportedNameClashException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.logging
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_logger import XLogger as XLogger_9a510aa7

class XLoggerPool(ABC):
    """
    implements a pool for named XLogger instances
    
    **since**
    
        OOo 2.3

    See Also:
        `API XLoggerPool <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.logging'
    __ooo_full_ns__: str = 'com.sun.star.logging.XLoggerPool'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.logging.XLoggerPool'

    @abstractmethod
    def getDefaultLogger(self) -> XLogger_9a510aa7:
        """
        retrieves a logger with the default name \"org.openoffice.logging.DefaultLogger\".
        
        Calling this method is equivalent to calling getNamedLogger( \"org.openoffice.logging.DefaultLogger\" ).
        """
        ...
    @abstractmethod
    def getNamedLogger(self, Name: str) -> XLogger_9a510aa7:
        """
        retrieves a logger with the given name
        
        Multiple attempts to retrieve a logger with the same name will return the same instance.
        
        Newly created logger instances are initialized via configuration. See the configuration module /org.openoffice.Office.Logging for an explanation of the initialization pattern.
        """
        ...

__all__ = ['XLoggerPool']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..animations.x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..drawing.x_draw_page import XDrawPage as XDrawPage_b07a0b57
    from ..drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier_29650f1e
    from ..drawing.x_shape import XShape as XShape_8fd00a3d
    from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
    from .x_shape_event_listener import XShapeEventListener as XShapeEventListener_92a311b5
    from .x_slide_show_listener import XSlideShowListener as XSlideShowListener_81671154
    from .x_slide_show_view import XSlideShowView as XSlideShowView_3eb40fa9

class XSlideShow(XInterface_8f010a43):
    """
    Slide show interface to perform slide show presentations.
    
    This interface provides the necessary methods to run and control a slide show from a given set of XDrawPage slides. The slide show can be displayed simultaneously on multiple targets.
    
    Note: To control a running slide show inside a presentation, please use XPresentation2 and XSlideShowController.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XSlideShow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.XSlideShow'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.presentation.XSlideShow'

    @abstractmethod
    def addShapeEventListener(self, xListener: XShapeEventListener_92a311b5, xShape: XShape_8fd00a3d) -> None:
        """
        Add a shape event listener.
        
        This method adds a listener to the slide show, which will get notified when a mouse click is performed on the given shape. This can be used by clients of the slide show to trigger external actions, such as jumps to different slides.
        """
        ...
    @abstractmethod
    def addSlideShowListener(self, xListener: XSlideShowListener_81671154) -> None:
        """
        Add a slide show listener.
        
        This method adds a listener to the slide show, which will get notified when a registered shape is clicked upon, or a new slide is about to be displayed. Note that the listeners will not be notified, when the slide change is directly requested by one of the nextSlide(), previousSlide() or displaySlide() methods.
        """
        ...
    @abstractmethod
    def addView(self, xView: XSlideShowView_3eb40fa9) -> bool:
        """
        Add a view to the slide show.
        
        This method adds a view to the slide show. After successful completion of this method, the slide show will be visible on the added view, scaled according to the view's output area.
        """
        ...
    @abstractmethod
    def displaySlide(self, xSlide: XDrawPage_b07a0b57, xDrawPages: XDrawPagesSupplier_29650f1e, AnimationNode: XAnimationNode_1cf10eb9, aProperties: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        Jump to the given slide.
        
        This method ends all effects on the current slide, displays a possible slide transition, followed by the given slide. If the current slide is equal to the requested slide here, this method does nothing (this especially means, that any currently active effects will remain running).
        """
        ...
    @abstractmethod
    def getCurrentSlide(self) -> XDrawPage_b07a0b57:
        """
        Query the currently displayed slide.
        """
        ...
    @abstractmethod
    def nextEffect(self) -> bool:
        """
        Trigger the next effect of the slide show.
        
        This method triggers the next effect on the currently displayed slide. If there is currently no slide show running, this method does nothing. If there are no more effects on the current slide, a possible slide transition effect is issued and the next slide is displayed.
        """
        ...
    @abstractmethod
    def pause(self, bPauseShow: bool) -> bool:
        """
        Change the pause state of the slide show.
        
        This method either pauses the slide show (all currently running effects are stopped), or starts a previously stopped show again (all paused effects start again).
        """
        ...
    @abstractmethod
    def previousEffect(self) -> bool:
        """
        Undo the last effect in the main sequence of the slide show.
        
        The current slide is displayed as if the last user-triggered effect has never been triggered. If there is no previous effect on the current slide then slideEnded(true) is called at the registered XSlideShowListener objects, which can then trigger a change to the previous slide. Note that this command is executed asynchronously. Multiple calls to update() may be necessary to complete its execution. If there is currently no slide show running, this method does nothing.
        """
        ...
    @abstractmethod
    def registerUserPaintPolygons(self, xDocFactory: XMultiServiceFactory_191e0eb6) -> None:
        """
        Register drawn polygons in presentation mode.
        """
        ...
    @abstractmethod
    def removeShapeEventListener(self, xListener: XShapeEventListener_92a311b5, xShape: XShape_8fd00a3d) -> None:
        """
        Revoke a previously registered shape event listener.
        """
        ...
    @abstractmethod
    def removeSlideShowListener(self, xListener: XSlideShowListener_81671154) -> None:
        """
        Revoke a previously registered slide show listener.
        """
        ...
    @abstractmethod
    def removeView(self, xView: XSlideShowView_3eb40fa9) -> bool:
        """
        Remove view from the slide show.
        
        This method removes the given view from the slide show. After successful completion of this method, the slide show will cease to display on this view.
        """
        ...
    @abstractmethod
    def setProperty(self, aShowProperty: PropertyValue_c9610c73) -> bool:
        """
        Change a property of the slide show.
        """
        ...
    @abstractmethod
    def setShapeCursor(self, xShape: XShape_8fd00a3d, nPointerShape: int) -> None:
        """
        Set a special mouse cursor for a shape.
        
        This method requests the slide show to display a special cursor, whenever the mouse is hovering over the given shape.
        """
        ...
    @abstractmethod
    def startShapeActivity(self, xShape: XShape_8fd00a3d) -> bool:
        """
        Start a shape-intrinsic animation or activity.
        
        This method starts an animation or activity intrinsic to the given shape. Shape-intrinsic activities are things like video playback for multimedia shapes, sounds, GIF animations and drawing layer animations (flipping between shapes in a group, or scroll text).
        """
        ...
    @abstractmethod
    def stopShapeActivity(self, xShape: XShape_8fd00a3d) -> bool:
        """
        Stop a shape-intrinsic animation or activity.
        
        This method stops an animation or activity intrinsic to the given shape. Shape-intrinsic activities are things like video playback for multimedia shapes, sounds, GIF animations and drawing layer animations (flipping between shapes in a group, or scroll text).
        """
        ...
    @abstractmethod
    def update(self, nNextTimeout: float) -> bool:
        """
        Update the animations.
        
        This method updates all currently active slide animations. The XSlideShow implementations do not render animations automatically, but must be called from their clients. This allows for various update mechanisms to be employed, ranging from a dedicated rendering thread, over timer-based updates, to rendering in an idle function. Either way, the client of this interface decide about the details.

        * ``nNextTimeout`` is an out direction argument.
        """
        ...

__all__ = ['XSlideShow']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
from ..lang.x_multi_component_factory import XMultiComponentFactory as XMultiComponentFactory_381b0f98

class CanvasFactory(XMultiComponentFactory_381b0f98):
    """
    Service Class

    The CanvasFactory is used to create the Canvas objects, evaluating the user's configuration preferences from.
    
    /org.openoffice.VCL/Settings/Canvas/PreferredServices.
    
    The latter specifies a string list of service names to use.
    
    Instantiating this service, you can use its com.sun.star.lang.XMultiComponentFactory interface to create Canvas objects, passing an empty string as service specifier (default). If you want to manually override the configured service list, you can pass a service name to try first.
    
    **since**
    
        OOo 2.0

    See Also:
        `API CanvasFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1rendering_1_1CanvasFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.CanvasFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['CanvasFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.mozilla.menu_multiple_change import MenuMultipleChange as MenuMultipleChange
from ...lo.mozilla.menu_proxy import MenuProxy as MenuProxy
from ...lo.mozilla.menu_proxy_listener import MenuProxyListener as MenuProxyListener
from ...lo.mozilla.menu_single_change import MenuSingleChange as MenuSingleChange
from ...lo.mozilla.mozilla_bootstrap import MozillaBootstrap as MozillaBootstrap
from ...lo.mozilla.mozilla_product_type import MozillaProductType as MozillaProductType
from ...lo.mozilla.x_close_session_listener import XCloseSessionListener as XCloseSessionListener
from ...lo.mozilla.x_code_proxy import XCodeProxy as XCodeProxy
from ...lo.mozilla.x_menu_proxy import XMenuProxy as XMenuProxy
from ...lo.mozilla.x_menu_proxy_listener import XMenuProxyListener as XMenuProxyListener
from ...lo.mozilla.x_mozilla_bootstrap import XMozillaBootstrap as XMozillaBootstrap
from ...lo.mozilla.x_profile_discover import XProfileDiscover as XProfileDiscover
from ...lo.mozilla.x_profile_manager import XProfileManager as XProfileManager
from ...lo.mozilla.x_proxy_runner import XProxyRunner as XProxyRunner



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing


class EnhancedCustomShapeParameterType(object):
    """
    Const Class

    defines how an EnhancedCustomShapeParameter has to be interpreted

    See Also:
        `API EnhancedCustomShapeParameterType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeParameterType'
    __ooo_type_name__: str = 'const'

    NORMAL = 0
    """
    the value of the point component is normal, the Coordinate is taken as it is
    """
    EQUATION = 1
    """
    the value of the point component has to be interpreted as index to an Equation
    """
    ADJUSTMENT = 2
    """
    the value of the point component has to be interpreted as index into the list of AdjustmentValues
    """
    LEFT = 3
    """
    the logical left border of the CustomShape is used
    """
    TOP = 4
    """
    the logical top border of the CustomShape is used
    """
    RIGHT = 5
    """
    the logical right border of the CustomShape is used
    """
    BOTTOM = 6
    """
    the logical bottom border of the CustomShape is used
    """
    XSTRETCH = 7
    """
    the x value of the stretch point is used
    """
    YSTRETCH = 8
    """
    the y value of the stretch point is used
    """
    HASSTROKE = 9
    """
    If the shape has a line style, a value of 1 is used.
    """
    HASFILL = 10
    """
    If the shape has a fill style, a value of 1 is used.
    """
    WIDTH = 11
    """
    The width of the svg:viewBox is used.
    """
    HEIGHT = 12
    """
    The height of the svg:viewBox is used.
    """
    LOGWIDTH = 13
    """
    The logical width of the shape is used.
    """
    LOGHEIGHT = 14
    """
    The logical height of the shape is used.
    """

__all__ = ['EnhancedCustomShapeParameterType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .password_request import PasswordRequest as PasswordRequest_d7280cf7
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from .password_request_mode import PasswordRequestMode as PasswordRequestMode_ec10e7c

class DocumentPasswordRequest(PasswordRequest_d7280cf7):
    """
    Exception Class

    this request specifies the mode in which the password should be asked
    
    It is supported by InteractionHandler service, and can be used to interact for a document password. Continuations for using with the mentioned service are Abort and Approve.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DocumentPasswordRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1task_1_1DocumentPasswordRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.DocumentPasswordRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.task.DocumentPasswordRequest'
    __pyunostruct__: str = 'com.sun.star.task.DocumentPasswordRequest'

    typeName: str = 'com.sun.star.task.DocumentPasswordRequest'
    """Literal Constant ``com.sun.star.task.DocumentPasswordRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, Mode: typing.Optional[PasswordRequestMode_ec10e7c] = PasswordRequestMode_ec10e7c.PASSWORD_CREATE, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Mode (PasswordRequestMode, optional): Mode value.
            Name (str, optional): Name value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "Mode": Mode,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        inst_keys = ('Name',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Name(self) -> str:
        """
        the name of the document (more properly, the URL of the document)
        """
        return self._name
    
    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['DocumentPasswordRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_dictionary_list import XDictionaryList as XDictionaryList_3a070f7f
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5

class XSearchableDictionaryList(XDictionaryList_3a070f7f):
    """
    allows searching for an entry in all dictionaries of the dictionary-list.
    
    Only active dictionaries of a suitable language will be searched for the entry. The language is suitable if it is the same as the dictionary's language or the dictionary may hold entries of all languages.

    See Also:
        `API XSearchableDictionaryList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XSearchableDictionaryList.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XSearchableDictionaryList'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XSearchableDictionaryList'

    @abstractmethod
    def queryDictionaryEntry(self, aWord: str, aLocale: Locale_70d308fa, bSearchPosDics: bool, bSpellEntry: bool) -> XDictionaryEntry_49ef0ff5:
        """
        looks for an entry for a given word in the list of dictionaries.
        """
        ...

__all__ = ['XSearchableDictionaryList']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XBackendEntities(XInterface_8f010a43):
    """
    Provides functionality relating to common and supported entities for a configuration data backend.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XBackendEntities <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XBackendEntities.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XBackendEntities'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XBackendEntities'

    @abstractmethod
    def getAdminEntity(self) -> str:
        """
        provides the entity id of an entity for general administrative access.
        
        The admin entity is an entity that should be used to read and manage configuration data that applies to all entities within the backend.
        """
        ...
    @abstractmethod
    def getOwnerEntity(self) -> str:
        """
        provides the entity id of the owner entity of the backend.
        
        The owner entity is the default entity for the backend. For normal configuration data access the owner entity should always be used.
        """
        ...
    @abstractmethod
    def isEqualEntity(self, aEntity: str, aOtherEntity: str) -> bool:
        """
        determines, if two given entity ids denote the same entity.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def supportsEntity(self, aEntity: str) -> bool:
        """
        determines, if a given entity id exists in this backend.

        Raises:
            BackendAccessException: ``BackendAccessException``
        """
        ...

__all__ = ['XBackendEntities']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.tools
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ...container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from ...lang.x_component import XComponent as XComponent_98dc0ab5
    from ..x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer_66e310b9
    from .x_data_source_meta_data import XDataSourceMetaData as XDataSourceMetaData_547c0fe4
    from .x_object_names import XObjectNames as XObjectNames_ed550d43
    from .x_table_name import XTableName as XTableName_d3140c61

class XConnectionTools(ABC):
    """
    encapsulates various useful functionality around a com.sun.star.sdb.Connection
    
    Most of the functionality provided here is meaningful only relative to a given database connection. For instance, for quoting table names, you need the meta data instance of the connection. Thus, the entry point for obtaining a XConnectionTools instance is the com.sun.star.sdb.Connection service.
    
    Note that nearly all functionality provided by this interface is also available by other means, it's only provided here for convenience purposes.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XConnectionTools <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XConnectionTools.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.tools'
    __ooo_full_ns__: str = 'com.sun.star.sdb.tools.XConnectionTools'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.tools.XConnectionTools'

    @abstractmethod
    def createTableName(self) -> XTableName_d3140c61:
        """
        creates an instance supporting the XTableName interface, which can be used to manipulate table names for various purposes.
        
        The returned object is guaranteed to not be NULL.
        """
        ...
    @abstractmethod
    def getComposer(self, commandType: int, command: str) -> XSingleSelectQueryComposer_66e310b9:
        """
        get the composer initialized with a command and command type.
        """
        ...
    @abstractmethod
    def getDataSourceMetaData(self) -> XDataSourceMetaData_547c0fe4:
        """
        provides access to the application-level data source meta data
        """
        ...
    @abstractmethod
    def getFieldsByCommandDescriptor(self, commandType: int, command: str, keepFieldsAlive: XComponent_98dc0ab5) -> XNameAccess_e2ab0cf6:
        """
        get fields for a result set given by a \"command descriptor\"
        
        A command descriptor here means:

        * ``keepFieldsAlive`` is an out direction argument.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getObjectNames(self) -> XObjectNames_ed550d43:
        """
        returns an instance supporting the XObjectNames interface, which provides access to functionality around table and query names.
        
        The returned object is guaranteed to not be NULL.
        """
        ...

__all__ = ['XConnectionTools']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from .x_invocation_adapter_factory2 import XInvocationAdapterFactory2 as XInvocationAdapterFactory2_a0fe11da

class InvocationAdapterFactory(XInvocationAdapterFactory2_a0fe11da):
    """
    Service Class

    Provides functionality to create an adapter that supports (a) special interface type(s) and maps calls to the interface's methods to an invocation interface.
    
    An adapter like this allows generic dispatch interfaces to meet interface requirements, e.g. if a specific listener interface has to be passed to an add...Listener method.
    
    The adapter has to support com.sun.star.script.XInvocationAdapterFactory. The adapter may also support com.sun.star.script.XInvocationAdapterFactory2.

    See Also:
        `API InvocationAdapterFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1script_1_1InvocationAdapterFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.InvocationAdapterFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['InvocationAdapterFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from .rotation_descriptor import RotationDescriptor as RotationDescriptor_2cec0f63
from .shadow_properties import ShadowProperties as ShadowProperties_e350e87
from .shape import Shape as Shape_85cc09e5
from .text import Text as Text_7c140999
if typing.TYPE_CHECKING:
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909
    from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
    from .bar_code import BarCode as BarCode_99e10a84
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from com.sun.star.drawing.ColorMode import ColorModeProto

class GraphicObjectShape(RotationDescriptor_2cec0f63, ShadowProperties_e350e87, Shape_85cc09e5, Text_7c140999):
    """
    Service Class

    This service is for a graphic shape.
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API GraphicObjectShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicObjectShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.GraphicObjectShape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AdjustBlue(self) -> int:
        """
        If this property is set, the blue channel of this graphic shape is adjusted by the given signed percent value.
        """
        ...

    @abstractproperty
    def AdjustContrast(self) -> int:
        """
        If this property is set, the contrast of this graphic shape is adjusted by the given signed percent value.
        """
        ...

    @abstractproperty
    def AdjustGreen(self) -> int:
        """
        If this property is set, the green channel of this graphic shape is adjusted by the given signed percent value.
        """
        ...

    @abstractproperty
    def AdjustLuminance(self) -> int:
        """
        If this property is set, the luminance of this graphic shape is adjusted by the given signed percent value.
        """
        ...

    @abstractproperty
    def AdjustRed(self) -> int:
        """
        If this property is set, the red channel of this graphic shape is adjusted by the given signed percent value.
        """
        ...

    @abstractproperty
    def BarCodeProperties(self) -> BarCode_99e10a84:
        """
        Shape as a QR Code.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def Gamma(self) -> float:
        """
        If this property is set, the gamma value of this graphic shape is adjusted by the given value.
        """
        ...

    @abstractproperty
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        This is the graphic that represents this graphic shape.
        """
        ...

    @abstractproperty
    def GraphicColorMode(self) -> ColorModeProto:
        """
        This property selects the color mode that is used for rendering.
        """
        ...

    @abstractproperty
    def GraphicObjectFillBitmap(self) -> XBitmap_70cd0909:
        """
        This is the bitmap that represents this graphic shape.
        """
        ...

    @abstractproperty
    def GraphicStreamURL(self) -> str:
        """
        This is a url to the stream (\"in document\" or linked graphic) for this graphic shape.
        """
        ...

    @abstractproperty
    def GraphicURL(self) -> str:
        """
        This is a url to the source bitmap for this graphic shape.
        
        Note the new behaviour since it was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When a URL is set, then it will load the image and set the Graphic property.
        """
        ...

    @abstractproperty
    def ImageMap(self) -> XIndexContainer_1c040ebe:
        """
        This property contains an image map for this graphic.
        """
        ...

    @abstractproperty
    def IsSignatureLine(self) -> bool:
        """
        Whether this shape is actually a signature line.
        """
        ...

    @abstractproperty
    def SignatureLineCanAddComment(self) -> bool:
        """
        Whether the user can attach a comment at signing time.
        """
        ...

    @abstractproperty
    def SignatureLineId(self) -> str:
        """
        The ID of the signature line, used to connect to a signature.
        """
        ...

    @abstractproperty
    def SignatureLineIsSigned(self) -> bool:
        """
        Whether the signature line is signed using a digital signature.
        """
        ...

    @abstractproperty
    def SignatureLineShowSignDate(self) -> bool:
        """
        Whether the signing date should be shown in the shape.
        """
        ...

    @abstractproperty
    def SignatureLineSigningInstructions(self) -> str:
        """
        Signing instructions, to be shown at signing time.
        """
        ...

    @abstractproperty
    def SignatureLineSuggestedSignerEmail(self) -> str:
        """
        Suggested Signer Email.
        """
        ...

    @abstractproperty
    def SignatureLineSuggestedSignerName(self) -> str:
        """
        Suggested Signer, Name of the Signer.
        """
        ...

    @abstractproperty
    def SignatureLineSuggestedSignerTitle(self) -> str:
        """
        Suggested Signer, Line 2 (Title or additional information)
        """
        ...

    @abstractproperty
    def SignatureLineUnsignedImage(self) -> XGraphic_a4da0afc:
        """
        Image to be displayed when the signature line is unsigned.
        
        Images for signed signature lines (valid and invalid) are to be retrieved via com.sun.star.security.DocumentSignatureInformation (you can get the matching signature with the SignatureLineId property).
        """
        ...

    @abstractproperty
    def Transparency(self) -> int:
        """
        If this property is set, the transparency value of this graphic shape is adjusted by the given unsigned percent value.
        
        100% is fully transparent, 0% is fully opaque.
        """
        ...


__all__ = ['GraphicObjectShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.drawing.EnhancedCustomShapeTextPathMode import EnhancedCustomShapeTextPathModeProto

class EnhancedCustomShapeTextPathMode(Enum):
    """
    Enum Class

    ENUM EnhancedCustomShapeTextPathMode

    See Also:
        `API EnhancedCustomShapeTextPathMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeTextPathMode'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.EnhancedCustomShapeTextPathMode'

    NORMAL = cast("EnhancedCustomShapeTextPathModeProto", 'NORMAL')
    """
    the text is drawn along the path without scaling.
    
    the point is normal, from the curve discussion view.
    """
    PATH = cast("EnhancedCustomShapeTextPathModeProto", 'PATH')
    """
    the text is fit to the path.
    """
    SHAPE = cast("EnhancedCustomShapeTextPathModeProto", 'SHAPE')
    """
    the text is fit to the bounding box of the shape.
    """

__all__ = ['EnhancedCustomShapeTextPathMode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XLibraryContainerPassword(XInterface_8f010a43):
    """
    Extension of XLibraryContainer to provide password functionality.
    
    This interface should be implemented together with XLibraryContainer2

    See Also:
        `API XLibraryContainerPassword <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryContainerPassword.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XLibraryContainerPassword'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XLibraryContainerPassword'

    @abstractmethod
    def changeLibraryPassword(self, Name: str, OldPassword: str, NewPassword: str) -> None:
        """
        Changes the library's password.
        
        If the library wasn't password protected before: The OldPassword parameter has to be an empty string. Afterwards calls to isLibraryPasswordProtected and isLibraryPasswordVerified for this library will return true.
        
        If the library already was password protected: The OldPassword parameter has to be set to the previous defined password. If then the NewPassword parameter is an empty string the library password protection will be disabled afterwards (afterwards calls to isLibraryPasswordProtected for this library will return false). If the NewPassword parameter is not an empty string it will accepted as the new password for the library.
        
        If a library with the this name doesn't exist but isn't com.sun.star.container.NoSuchElementException is thrown.
        
        If the library exists and is password protected and a wrong OldPassword is passed to the method a com.sun.star.lang.IllegalArgumentException is thrown.
        
        If the library exists and isn't password protected and the OldPassword isn't an empty string or the library is read only a com.sun.star.lang.IllegalArgumentException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def isLibraryPasswordProtected(self, Name: str) -> bool:
        """
        Returns true if the accessed library item is protected by a password.
        
        If a library with the this name doesn't exist a com.sun.star.container.NoSuchElementException is thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def isLibraryPasswordVerified(self, Name: str) -> bool:
        """
        Returns true if the accessed library item is protected by a password (see isLibraryPasswordProtected) and the password was already verified with verifyLibraryPassword or if an initial password was set with changeLibraryPassword.
        
        If a library with the this name doesn't exist a com.sun.star.container.NoSuchElementException is thrown.
        
        If the library exists but isn't password protected a com.sun.star.lang.IllegalArgumentException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def verifyLibraryPassword(self, Name: str, Password: str) -> bool:
        """
        Verifies the library's password.
        
        If the correct password was passed, the method returns true and further calls to isLibraryPasswordVerified will also return true.
        
        If a library with the this name doesn't exist a com.sun.star.container.NoSuchElementException is thrown.
        
        If the library exists but isn't password protected a com.sun.star.lang.IllegalArgumentException is thrown.
        
        If the library password is already verified a com.sun.star.lang.IllegalArgumentException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XLibraryContainerPassword']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.runtime
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ...awt.x_control import XControl as XControl_7a9c098d
    from .x_filter_controller_listener import XFilterControllerListener as XFilterControllerListener_381416

class XFilterController(ABC):
    """
    provides access to a form based filter for a database form
    
    In a form based filter, form controls bound to a searchable database field are replaced with a control which allows entering a search expression. This so-called predicate expression is basically a part of an SQL WHERE clause, but without the part denoting the database column. For instance, if you have a form control bound to a table column named Name, then entering the string LIKE 'Smith' effectively constitutes a SQL WHERE clause \"Name\" LIKE 'Smith'.
    
    In the actual document view, there are usually some relaxations to this. For instance, keywords such as LIKE might be localized, according to OpenOffice.org's UI locale. Also, for an equality criterion, the equality sign = is usually omitted. However, this interface here provides programmatic access to the form based filter, so those relaxations are not considered here.
    
    The filter maintained by a filter controller is, logically, a disjunctive normal form of an SQL WHERE class. That is, it is a disjunction of m terms, where each term is a conjunction of n clauses of the form <column> <predicate> <literal> or of the form <column> IS [NOT] NULL.
    
    n equals the number of filter controls which the filter controller is responsible for. This number doesn't change during one session of the form based filter. On the other hand, m, the number of disjunctive terms, is dynamic.
    
    With the above, there are potentially m * n predicate expressions (though usually only a fraction of those will actually exist). Since in a form based filter, there are only n filter controls, and each filter control displays exactly one predicate expression, this means that only a part of the complete filter can be displayed, in particular, only one disjunctive term can be displayed at a time. Thus, the filter controller knows the concept of an active term, denoted by the ActiveTerm attribute, controls which of the terms is currently displayed in the form controls.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XFilterController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.XFilterController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.runtime.XFilterController'

    @abstractmethod
    def addFilterControllerListener(self, Listener: XFilterControllerListener_381416) -> None:
        """
        registers a listener to be notified of certain changes in the form based filter.
        
        Registering the same listener multiple times results in multiple notifications of the same event, and also requires multiple revocations of the listener.
        """
        ...
    @abstractmethod
    def appendEmptyDisjunctiveTerm(self) -> None:
        """
        appends an empty disjunctive term to the list of terms.
        """
        ...
    @abstractmethod
    def getFilterComponent(self, Component: int) -> XControl_7a9c098d:
        """
        retrieves the filter component with the given index.
        
        The filter control has the same control model as the control which it stands in for. Consequently, you can use this method to obtain the database column which the filter control works on, by examining the control model's BoundField property.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getPredicateExpressions(self) -> typing.Tuple[typing.Tuple[str, ...], ...]:
        """
        retrieves the entirety of the predicate expressions represented by the filter controller.
        
        Each element of the returned sequence is a disjunctive term, having exactly FilterComponents elements, which denote the single predicate expressions of this term.
        """
        ...
    @abstractmethod
    def removeDisjunctiveTerm(self, Term: int) -> None:
        """
        removes a given disjunctive term

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def removeFilterControllerListener(self, Listener: XFilterControllerListener_381416) -> None:
        """
        revokes a listener which was previously registered to be notified of certain changes in the form based filter.
        """
        ...
    @abstractmethod
    def setPredicateExpression(self, Component: int, Term: int, PredicateExpression: str) -> None:
        """
        sets a given predicate expression

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractproperty
    def ActiveTerm(self) -> int:
        """
        denotes the active term of the filter controller.
        """
        ...

    @abstractproperty
    def DisjunctiveTerms(self) -> int:
        """
        is the number of disjunctive terms of the filter expression represented by the form based filter.
        """
        ...

    @abstractproperty
    def FilterComponents(self) -> int:
        """
        is the number of filter components, or filter controls, which the filter controller is responsible for.
        
        This number is constant during one session of the form based filter.
        """
        ...


__all__ = ['XFilterController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration
from __future__ import annotations
from .configuration_access import ConfigurationAccess as ConfigurationAccess_a5d4122a
from .group_update import GroupUpdate as GroupUpdate_20340ef0
from .set_update import SetUpdate as SetUpdate_2530e0f
from .update_root_element import UpdateRootElement as UpdateRootElement_814f1151

class ConfigurationUpdateAccess(ConfigurationAccess_a5d4122a, GroupUpdate_20340ef0, SetUpdate_2530e0f, UpdateRootElement_814f1151):
    """
    Service Class

    provides modifying access to a fragment of the configuration hierarchy.
    
    Extends ConfigurationAccess to support modifying values or inserting and removing elements.
    
    Descendants of this service also implement this service unless they are marked read-only (which is indicated by attribute com.sun.star.beans.PropertyAttribute.READONLY), in which case they only need implement ConfigurationAccess.
    
    The classification of implementations that is described for ConfigurationAccess applies to implementations of this service as well. Therefore an implementation will support one of several alternate services describing its Container role and one of several alternate services describing its Element role. These services are extensions of the respective services documented for ConfigurationAccess.

    See Also:
        `API ConfigurationUpdateAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationUpdateAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration'
    __ooo_full_ns__: str = 'com.sun.star.configuration.ConfigurationUpdateAccess'
    __ooo_type_name__: str = 'service'


__all__ = ['ConfigurationUpdateAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tree
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .x_tree_node import XTreeNode as XTreeNode_baaf0ba0

class XTreeEditListener(XEventListener_c7230c4a):
    """
    You can implement this interface and register with XTreeControl.addTreeEditListener() to get notifications when editing of a node starts and ends.
    
    You have to set the TreeControlModel.Editable property to TRUE before a tree supports editing.

    See Also:
        `API XTreeEditListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeEditListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.XTreeEditListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.tree.XTreeEditListener'

    @abstractmethod
    def nodeEdited(self, Node: XTreeNode_baaf0ba0, NewText: str) -> None:
        """
        This method is called from the TreeControl implementation when editing of Node is finished and was not canceled.
        
        Implementations that register a XTreeEditListener must update the display value at the Node.
        """
        ...
    @abstractmethod
    def nodeEditing(self, Node: XTreeNode_baaf0ba0) -> None:
        """
        This method is called from the TreeControl implementation when editing of Node is requested by calling XTreeControl.startEditingAtNode().

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
        """
        ...

__all__ = ['XTreeEditListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.lang
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43


class EventObject(object):
    """
    Struct Class

    specifies the base for all event objects and identifies the source of the event.

    See Also:
        `API EventObject <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1lang_1_1EventObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.EventObject'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.lang.EventObject'
    """Literal Constant ``com.sun.star.lang.EventObject``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
        """
        super().__init__()

        if isinstance(Source, EventObject):
            oth: EventObject = Source
            self.Source = oth.Source
            return

        kargs = {
            "Source": Source,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._source = kwargs["Source"]


    @property
    def Source(self) -> XInterface_8f010a43:
        """
        refers to the object that fired the event.
        """
        return self._source

    @Source.setter
    def Source(self, value: XInterface_8f010a43) -> None:
        self._source = value


__all__ = ['EventObject']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D
with suppress(ImportError):
    from ...dyn.geometry.affine_matrix3_d import AffineMatrix3D as AffineMatrix3D
with suppress(ImportError):
    from ...dyn.geometry.elliptical_arc import EllipticalArc as EllipticalArc
with suppress(ImportError):
    from ...dyn.geometry.integer_bezier_segment2_d import IntegerBezierSegment2D as IntegerBezierSegment2D
with suppress(ImportError):
    from ...dyn.geometry.integer_point2_d import IntegerPoint2D as IntegerPoint2D
with suppress(ImportError):
    from ...dyn.geometry.integer_rectangle2_d import IntegerRectangle2D as IntegerRectangle2D
with suppress(ImportError):
    from ...dyn.geometry.integer_size2_d import IntegerSize2D as IntegerSize2D
with suppress(ImportError):
    from ...dyn.geometry.matrix2_d import Matrix2D as Matrix2D
with suppress(ImportError):
    from ...dyn.geometry.real_bezier_segment2_d import RealBezierSegment2D as RealBezierSegment2D
with suppress(ImportError):
    from ...dyn.geometry.real_point2_d import RealPoint2D as RealPoint2D
with suppress(ImportError):
    from ...dyn.geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D
with suppress(ImportError):
    from ...dyn.geometry.real_rectangle3_d import RealRectangle3D as RealRectangle3D
with suppress(ImportError):
    from ...dyn.geometry.real_size2_d import RealSize2D as RealSize2D
with suppress(ImportError):
    from ...dyn.geometry.x_mapping2_d import XMapping2D as XMapping2D



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..chart.x_complex_description_access import XComplexDescriptionAccess as XComplexDescriptionAccess_7a521120

class XAnyDescriptionAccess(XComplexDescriptionAccess_7a521120):
    """
    Offers any access to column and row descriptions.
    
    This allows to set date values as categories.
    
    Can be obtained from interface XChartDocument via method getData().
    
    **since**
    
        OOo 3.4

    See Also:
        `API XAnyDescriptionAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XAnyDescriptionAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XAnyDescriptionAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XAnyDescriptionAccess'

    @abstractmethod
    def getAnyColumnDescriptions(self) -> typing.Tuple[typing.Tuple[object, ...], ...]:
        """
        retrieves the descriptions for all columns.
        """
        ...
    @abstractmethod
    def getAnyRowDescriptions(self) -> typing.Tuple[typing.Tuple[object, ...], ...]:
        """
        retrieves the descriptions for all rows.
        """
        ...
    @abstractmethod
    def setAnyColumnDescriptions(self, rColumnDescriptions: typing.Tuple[typing.Tuple[object, ...], ...]) -> None:
        """
        sets the descriptions for all columns.
        """
        ...
    @abstractmethod
    def setAnyRowDescriptions(self, rRowDescriptions: typing.Tuple[typing.Tuple[object, ...], ...]) -> None:
        """
        sets the descriptions for all rows.
        """
        ...

__all__ = ['XAnyDescriptionAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_ieee_double_read_only_bitmap import XIeeeDoubleReadOnlyBitmap as XIeeeDoubleReadOnlyBitmap_bfd0126c
if typing.TYPE_CHECKING:
    from ..geometry.integer_point2_d import IntegerPoint2D as IntegerPoint2D_8f0dc2
    from ..geometry.integer_rectangle2_d import IntegerRectangle2D as IntegerRectangle2D_3c5c0f4d
    from .floating_point_bitmap_layout import FloatingPointBitmapLayout as FloatingPointBitmapLayout_c66812df

class XIeeeDoubleBitmap(XIeeeDoubleReadOnlyBitmap_bfd0126c):
    """
    This is a specialized interface for bitmaps containing IEEE doubles for their color components.

    See Also:
        `API XIeeeDoubleBitmap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XIeeeDoubleBitmap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XIeeeDoubleBitmap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XIeeeDoubleBitmap'

    @abstractmethod
    def setData(self, data: typing.Tuple[float, ...], bitmapLayout: FloatingPointBitmapLayout_c66812df, rect: IntegerRectangle2D_3c5c0f4d) -> None:
        """
        Set raw data of a bitmap.
        
        Set raw data of a bitmap, in the format as defined by getMemoryLayout(). With the given rectangle, a subset of the bitmap can be changed. When setting subsets of the bitmap, the same scanline padding takes place as when the whole bitmap is changed.
        
        When setting data on volatile bitmaps, always call isValid() before, and retrieve a new memory layout via getMemoryLayout(). At least under Windows, the memory layout can change for the same bitmap, if the user e.g. switches the screen resolution. Thus, this method will throw an IllegalArgumentException, if the memory layout changed between a call to getMemoryLayout() and setData().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def setPixel(self, color: typing.Tuple[float, ...], bitmapLayout: FloatingPointBitmapLayout_c66812df, pos: IntegerPoint2D_8f0dc2) -> None:
        """
        Set a single pixel of the bitmap with the given color value.
        
        When setting data on volatile bitmaps, always call isValid() before, and retrieve a new memory layout via getMemoryLayout(). At least under Windows, the memory layout can change for the same bitmap, if the user e.g. switches the screen resolution. Thus, this method will throw an IllegalArgumentException, if the memory layout changed between a call to getMemoryLayout() and setPixel().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XIeeeDoubleBitmap']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class ImagePosition(object):
    """
    Const Class

    specifies the position of an image, relative to another object

    See Also:
        `API ImagePosition <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1ImagePosition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.ImagePosition'
    __ooo_type_name__: str = 'const'

    LeftTop = 0
    """
    specifies that the image should be positioned at the left of, and top-aligned to, the other object
    """
    LeftCenter = 1
    """
    specifies that the image should be positioned at the left of, and vertically centered to, the other object
    """
    LeftBottom = 2
    """
    specifies that the image should be positioned at the left of, and bottom-aligned to, the other object
    """
    RightTop = 3
    """
    specifies that the image should be positioned at the right of, and top-aligned to, the other object
    """
    RightCenter = 4
    """
    specifies that the image should be positioned at the right of, and vertically centered to, the other object
    """
    RightBottom = 5
    """
    specifies that the image should be positioned at the right of, and bottom-aligned to, the other object
    """
    AboveLeft = 6
    """
    specifies that the image should be positioned above and left-aligned to the other object
    """
    AboveCenter = 7
    """
    specifies that the image should be positioned above and horizontally centered to the other object
    """
    AboveRight = 8
    """
    specifies that the image should be positioned above and right-aligned to the other object
    """
    BelowLeft = 9
    """
    specifies that the image should be positioned below and left-aligned to the other object
    """
    BelowCenter = 10
    """
    specifies that the image should be positioned below and horizontally centered to the other object
    """
    BelowRight = 11
    """
    specifies that the image should be positioned below and right-aligned centered to the other object
    """
    Centered = 12
    """
    specifies that the image should be horizontally and vertically centered to the other object.
    """

__all__ = ['ImagePosition']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc


class TransactionIsolation(object):
    """
    Const Class

    distinguishes different possible transaction isolation levels.

    See Also:
        `API TransactionIsolation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1TransactionIsolation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.TransactionIsolation'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    indicates that transactions are not supported.
    """
    READ_UNCOMMITTED = 1
    """
    Dirty reads, non-repeatable reads and phantom reads can occur.
    
    This level allows a row changed by one transaction to be read by another transaction before any changes in that row have been committed (a \"dirty read\"). If any of the changes are rolled back, the second transaction will have retrieved an invalid row.
    """
    READ_COMMITTED = 2
    """
    Dirty reads are prevented; non-repeatable reads and phantom reads can occur.
    
    This level only prohibits a transaction from reading a row with uncommitted changes in it.
    """
    REPEATABLE_READ = 4
    """
    Dirty reads and non-repeatable reads are prevented; phantom reads can occur.
    
    This level prohibits a transaction from reading a row with uncommitted changes in it, and it also prohibits the situation where one transaction reads a row, a second transaction alters the row, and the first transaction rereads the row, getting different values the second time (a \"non-repeatable read\").
    """
    SERIALIZABLE = 8
    """
    Dirty reads, non-repeatable reads and phantom reads are prevented.
    
    This level includes the prohibitions in REPEATABLE_READ and further prohibits the situation where one transaction reads all rows that satisfy a WHERE condition, a second transaction inserts a row that satisfies that WHERE condition, and the first transaction rereads for the same condition, retrieving the additional \"phantom\" row in the second read.
    """

__all__ = ['TransactionIsolation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.inspection
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class InteractiveSelectionResult(metaclass=UnoEnumMeta, type_name="com.sun.star.inspection.InteractiveSelectionResult", name_space="com.sun.star.inspection"):
        """Dynamically created class that represents ``com.sun.star.inspection.InteractiveSelectionResult`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.inspection.InteractiveSelectionResult import Cancelled as INTERACTIVE_SELECTION_RESULT_Cancelled
        from com.sun.star.inspection.InteractiveSelectionResult import ObtainedValue as INTERACTIVE_SELECTION_RESULT_ObtainedValue
        from com.sun.star.inspection.InteractiveSelectionResult import Pending as INTERACTIVE_SELECTION_RESULT_Pending
        from com.sun.star.inspection.InteractiveSelectionResult import Success as INTERACTIVE_SELECTION_RESULT_Success

        class InteractiveSelectionResult(uno.Enum):
            """
            Enum Class


            See Also:
                `API InteractiveSelectionResult <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.inspection.InteractiveSelectionResult', value)

            __ooo_ns__: str = 'com.sun.star.inspection'
            __ooo_full_ns__: str = 'com.sun.star.inspection.InteractiveSelectionResult'
            __ooo_type_name__: str = 'enum'

            Cancelled = INTERACTIVE_SELECTION_RESULT_Cancelled
            """
            The interactive selection of a property value was canceled.
            """
            ObtainedValue = INTERACTIVE_SELECTION_RESULT_ObtainedValue
            """
            The interactive selection of a property value succeeded, a new property value has been obtained, but not yet set at the inspected component.

            In this case, the obtained value is passed to the caller of XPropertyHandler.onInteractivePropertySelection(), which is responsible for forwarding this value to the inspected component.
            """
            Pending = INTERACTIVE_SELECTION_RESULT_Pending
            """
            The interactive selection of a property value is still pending.
            """
            Success = INTERACTIVE_SELECTION_RESULT_Success
            """
            The interactive selection of a property value succeeded, and the new property value chosen by the user has already been set at the inspected component.
            """
    else:
        # keep document generators happy
        from ...lo.inspection.interactive_selection_result import InteractiveSelectionResult as InteractiveSelectionResult


__all__ = ['InteractiveSelectionResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XScaling(XInterface_8f010a43):
    """

    See Also:
        `API XScaling <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XScaling.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XScaling'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XScaling'

    @abstractmethod
    def doScaling(self, value: float) -> float:
        """
        Given a numeric value, return the scaled value that conforms to a predefined scaling rule.
        
        For instance, for linear scaling, given a x value, the method may return a y value as defined by y = Ax + B for predefined values of A and B.
        """
        ...
    @abstractmethod
    def getInverseScaling(self) -> XScaling:
        """
        Get an interface object that conforms to a scaling rule that is the reverse of the original scaling rule.
        """
        ...

__all__ = ['XScaling']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class WordType(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.WordType", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.WordType``"""
        pass

    class WordTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.WordType", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.WordType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import WordType as WordType
    else:
        # keep document generators happy
        from ...lo.i18n.word_type import WordType as WordType

    class WordTypeEnum(IntEnum):
        """
        Enum of Const Class WordType

        Constants to specify the type of words.
        
        Used with XBreakIterator.nextWord(), XBreakIterator.previousWord(), XBreakIterator.getWordBoundary(), XBreakIterator.getWordType(), XBreakIterator.isBeginWord(), XBreakIterator.isEndWord()
        """
        ANY_WORD = WordType.ANY_WORD
        """
        Any \"words\" - words in the meaning of same character types, collection of alphanumeric characters, or collection of non-alphanumeric characters.
        """
        ANYWORD_IGNOREWHITESPACES = WordType.ANYWORD_IGNOREWHITESPACES
        """
        Any \"words\" - words in the meaning of same character types, collection of alphanumeric characters, or collection of non-alphanumeric characters except blanks.
        """
        DICTIONARY_WORD = WordType.DICTIONARY_WORD
        """
        \"words\" - in the meaning of a collection of alphanumeric characters and some punctuations, like dot for abbreviation.
        """
        WORD_COUNT = WordType.WORD_COUNT
        """
        The mode for counting words, it will combine punctuations and spaces as word trail.
        """

__all__ = ['WordType', 'WordTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.mail
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..datatransfer.x_transferable import XTransferable as XTransferable_2d800f38
    from .mail_attachment import MailAttachment as MailAttachment_c6770c37

class XMailMessage(XInterface_8f010a43):
    """
    Represents a mail message.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XMailMessage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mail'
    __ooo_full_ns__: str = 'com.sun.star.mail.XMailMessage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.mail.XMailMessage'

    @abstractmethod
    def addAttachment(self, aMailAttachment: MailAttachment_c6770c37) -> None:
        """
        Add a file attachment to a mail message.
        
        param aMailAttachment [in] specifies a file which should be attached to this mail message.
        """
        ...
    @abstractmethod
    def addBccRecipient(self, sRecipientAddress: str) -> None:
        """
        Add a BCC recipients e-mail address to the list of recipients of this mail message.
        
        If the e-mail address doesn't conform to RFC 822 sending the mail message will fail.
        """
        ...
    @abstractmethod
    def addCcRecipient(self, sRecipientAddress: str) -> None:
        """
        Add a Cc recipients e-mail address to the list of recipients of this mail message.
        
        If the e-mail address doesn't conform to RFC 822 sending the mail message will fail.
        """
        ...
    @abstractmethod
    def addRecipient(self, sRecipientAddress: str) -> None:
        """
        Add a recipients e-mail address to the list of recipients of this mail message.
        
        If the e-mail address doesn't conform to RFC 822 sending the mail message will fail.
        """
        ...
    @abstractmethod
    def getAttachments(self) -> typing.Tuple[MailAttachment_c6770c37, ...]:
        """
        Return a sequence of MailAttachment's that will be attached to this mail message.
        """
        ...
    @abstractmethod
    def getBccRecipients(self) -> typing.Tuple[str, ...]:
        """
        Return a sequence of the e-mail addresses of all the BCC recipients of this mail message.
        """
        ...
    @abstractmethod
    def getCcRecipients(self) -> typing.Tuple[str, ...]:
        """
        Return a sequence of the e-mail addresses of all the Cc recipients of this mail message.
        """
        ...
    @abstractmethod
    def getRecipients(self) -> typing.Tuple[str, ...]:
        """
        Return a sequence of the e-mail addresses of all recipients of this mail message.
        """
        ...
    @abstractproperty
    def Body(self) -> XTransferable_2d800f38:
        """
        The body of the mail message.
        
        It is expected that the transferable delivers the data as a string. Although a transferable may support multiple data flavors only the first data flavor supplied will be used to retrieve the data and it is expected that the data will be provided as a string.
        """
        ...

    @abstractproperty
    def ReplyToAddress(self) -> str:
        """
        The e-mail address where replies on this mail message should be sent to.
        
        If the e-mail address doesn't conform to RFC 822 sending the mail message later will fail. If no ReplyToAddress is set replies go to the SenderAddress.
        """
        ...

    @abstractproperty
    def SenderAddress(self) -> str:
        """
        The e-mail address of the sender of this mail message.
        
        The e-mail address has to conform to RFC 822.
        """
        ...

    @abstractproperty
    def SenderName(self) -> str:
        """
        The display name of the sender of this mail message.
        """
        ...

    @abstractproperty
    def Subject(self) -> str:
        """
        The subject of a mail message.
        """
        ...


__all__ = ['XMailMessage']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .x_array import XArray as XArray_708108fb
    from .x_blob import XBlob as XBlob_6773087b
    from .x_clob import XClob as XClob_6777087c
    from .x_ref import XRef as XRef_5f110819
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XSQLInput(XInterface_8f010a43):
    """
    represents an input stream that contains a stream of values representing an instance of a SQL structured or distinct type.
    
    This interface, used only for custom mapping, is used by the driver behind the scenes, and a programmer never directly invokes SQLInput methods.
    
    When the method getObject is called with an object of a service implementing the interface SQLData , the SDBC driver calls the method com.sun.star.sdbc.XSQLData.getSQLType() to determine the SQL type of the user-defined type (UDT) being custom mapped. The driver creates an instance of com.sun.star.sdbc.XSQLInput , populating it with the attributes of the UDT. The driver then passes the input stream to the method com.sun.star.sdbc.XSQLData.readSQL() , which in turn calls the XSQLInput.readXXX methods in its implementation for reading the attributes from the input stream.

    See Also:
        `API XSQLInput <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLInput.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XSQLInput'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XSQLInput'

    @abstractmethod
    def readArray(self) -> XArray_708108fb:
        """
        reads an array from the stream.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readBinaryStream(self) -> XInputStream_98d40ab4:
        """
        reads the next attribute in the stream as sequence of bytes.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readBlob(self) -> XBlob_6773087b:
        """
        reads a BLOB from the stream.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readBoolean(self) -> bool:
        """
        reads the next attribute in the stream as boolean.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readByte(self) -> int:
        """
        reads the next attribute in the stream as byte.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readBytes(self) -> uno.ByteSequence:
        """
        reads the next attribute in the stream as sequence of bytes.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readCharacterStream(self) -> XInputStream_98d40ab4:
        """
        reads the next attribute in the stream as a Unicode string.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readClob(self) -> XClob_6777087c:
        """
        reads a CLOB from the stream.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readDate(self) -> Date_60040844:
        """
        reads the next attribute in the stream as date.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readDouble(self) -> float:
        """
        reads the next attribute in the stream as double.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readFloat(self) -> float:
        """
        reads the next attribute in the stream as float.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readInt(self) -> int:
        """
        reads the next attribute in the stream as long.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readLong(self) -> int:
        """
        reads the next attribute in the stream as hyper.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readObject(self) -> object:
        """
        returns the datum at the head of the stream as an any.
        
        The actual type of the any returned is determined by the default type mapping, and any customizations present in this stream's type map.
        
        A type map is registered with the stream by the SDBC driver before the stream is passed to the application.
        
        When the datum at the head of the stream is a SQL NULL, the method returns VOID. If the datum is a SQL structured or distinct type, it determines the SQL type of the datum at the head of the stream, constructs an object of the appropriate service, and calls the method com.sun.star.sdbc.XSQLData.readSQL() on that object, which reads additional data from the stream using the protocol described for that method.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readRef(self) -> XRef_5f110819:
        """
        reads a REF(&lt;structured-type&gt;) from the stream.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readShort(self) -> int:
        """
        reads the next attribute in the stream as short.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readString(self) -> str:
        """
        reads the next attribute in the stream as string.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readTime(self) -> Time_604e0855:
        """
        reads the next attribute in the stream as time.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def readTimestamp(self) -> DateTime_84de09d3:
        """
        reads the next attribute in the stream as datetime.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def wasNull(self) -> bool:
        """
        determines whether the last value read was null.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XSQLInput']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AnimationEndSync(metaclass=UnoConstMeta, type_name="com.sun.star.animations.AnimationEndSync", name_space="com.sun.star.animations"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.animations.AnimationEndSync``"""
        pass

    class AnimationEndSyncEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.animations.AnimationEndSync", name_space="com.sun.star.animations"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.animations.AnimationEndSync`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.animations import AnimationEndSync as AnimationEndSync
    else:
        # keep document generators happy
        from ...lo.animations.animation_end_sync import AnimationEndSync as AnimationEndSync

    class AnimationEndSyncEnum(IntEnum):
        """
        Enum of Const Class AnimationEndSync

        """
        FIRST = AnimationEndSync.FIRST
        """
        The par, excl, or media element's implicit duration ends with the earliest active end of all the child elements.
        
        This does not refer to the lexical first child, or to the first child to start, but rather refers to the first child to end its (first) active duration.
        """
        LAST = AnimationEndSync.LAST
        """
        The par, excl, or media element's implicit duration ends with the last active end of the child elements.
        
        This does not refer to the lexical last child, or to the last child to start, but rather refers to the last active end of all children that have a resolved, definite begin time. If the time container has no children with a resolved begin time, the time container ends immediately. If child elements have multiple begin times, or otherwise restart, the child elements must complete all instances of active durations for resolved begin times. This is the default value for par and excl elements.
        """
        ALL = AnimationEndSync.ALL
        """
        The par, excl, or media element's implicit duration ends when all of the child elements have ended their respective active durations.
        
        Elements with indefinite or unresolved begin times will keep the simple duration of the time container from ending. When all elements have completed the active duration one or more times, the parent time container can end.
        """
        MEDIA = AnimationEndSync.MEDIA
        """
        The time container element's implicit duration ends when the intrinsic media duration of the element ends.
        
        This must be defined by a host language. If the time container element does not define an intrinsic media duration, the host language must define the simple duration for the element. This is the default value for media time container elements.
        """

__all__ = ['AnimationEndSync', 'AnimationEndSyncEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..sdb.data_access_descriptor import DataAccessDescriptor as DataAccessDescriptor_6c50e2c
from ..task.x_job import XJob as XJob_5fa1082e
from .x_mail_merge_broadcaster import XMailMergeBroadcaster as XMailMergeBroadcaster_27c30f02
from ..util.x_cancellable import XCancellable as XCancellable_afc30b64
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..frame.x_model import XModel as XModel_7a6e095c
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c
    from ..sdbc.x_result_set import XResultSet as XResultSet_98e30aa7

class MailMerge(DataAccessDescriptor_6c50e2c, XPropertySet_bc180bfa, XJob_5fa1082e, XMailMergeBroadcaster_27c30f02, XCancellable_afc30b64):
    """
    Service Class

    Gives access to mail merge functionality.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API MailMerge <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.MailMerge'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BlindCopiesTo(self) -> typing.Tuple[str, ...]:
        """
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def CopiesTo(self) -> typing.Tuple[str, ...]:
        """
        contains a list of e-Mail addresses to
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def PrintOptions(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        contains the properties that are defined in <com.sun.star.view.PrintOptions>.
        
        This property is only evaluated for printer output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Selection(self) -> typing.Tuple[object, ...]:
        """
        contains a selection that refers to bookmarks of the ResultSet.
        
        This property is relevant in conjunction with the ResultSet only. A single element of this array describes a bookmark relative to the result set.Note that this implies that the ResultSet needs to support the com.sun.star.sdbcx.XRowLocate interface.
        
        If this array is empty, the whole result set, as described by ResultSet respectively the triple (DataSourceName, CommandType, Command).
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def ActiveConnection(self) -> XConnection_a36a0b0c:
        """
        contains the connection to the database.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def AddressFromColumn(self) -> str:
        """
        contains the name of the data base column that contains the e-Mail address to the e-Mail to.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def AttachmentFilter(self) -> str:
        """
        contains the name of the document filter to save the attached mail merge document.
        
        This property is only valid if \"SendAsAttachment\" is set to TRUE.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def AttachmentName(self) -> str:
        """
        contains the name of the attachment.
        
        This property is only valid if \"SendAsAttachment\" is set to TRUE.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Command(self) -> str:
        """
        contains the database command.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def CommandType(self) -> int:
        """
        determines the type of the database command as described in com.sun.star.sdb.CommandType
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def DataSourceName(self) -> str:
        """
        contains the name of the data source that is to be used for merging.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def DocumentURL(self) -> str:
        """
        contains the URL of a text document that is to be processed.
        
        If this property is not set an empty document is created.
        """
        ...

    @abstractproperty
    def EscapeProcessing(self) -> bool:
        """
        returns if escape processing is on or off.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def FileNameFromColumn(self) -> bool:
        """
        determines whether file names of created files are generated using the content of a database column.
        
        This property is only evaluated for file output.
        """
        ...

    @abstractproperty
    def FileNamePrefix(self) -> str:
        """
        contains the name of the column to generate the output file names.
        
        If FileNameFromColumn is true the content of the related column is added to the OutputURL.
        
        If \"OutputURL\" or \"FileNamePrefix\" are empty the missing value is generated from the location or title of the source documents.
        
        This property is only evaluated for file output.
        """
        ...

    @abstractproperty
    def Filter(self) -> str:
        """
        contains a filter expression for an SQL statement.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def InServerPassword(self) -> str:
        """
        Contains the password of the incoming mail server.
        
        It is necessary to set this if the mail server configuration is set to \"SMTP after POP\" authentication and the password is not already stored in the configuration for security reasons.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def MailBody(self) -> str:
        """
        contains the text of the mail body.
        
        This property is only valid if the property \"SendAsAttachment\" is set to TRUE
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Model(self) -> XModel_7a6e095c:
        """
        provides access to the model of the document to be processed.
        
        This property will automatically be set to the documents model if a document URL was set.
        """
        ...

    @abstractproperty
    def OutServerPassword(self) -> str:
        """
        Contains the password of the outgoing mail server.
        
        It is necessary to set this if the password is not already stored in the configuration for security reasons.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def OutputType(self) -> int:
        """
        determines the destination of the mail merge action.
        """
        ...

    @abstractproperty
    def OutputURL(self) -> str:
        """
        contains the path where generated files are created.
        
        If \"OutputURL\" or \"FileNamePrefix\" are empty the missing value is generated from the location or title of the source documents.
        
        This property is only evaluated for file output.
        """
        ...

    @abstractproperty
    def ResultSet(self) -> XResultSet_98e30aa7:
        """
        provides access to a com.sun.star.sdbc.XResultSet of a com.sun.star.sdbc.ResultSet service.
        
        Note that any superservices of com.sun.star.sdbc.ResultSet are also allowed. Especially, this member can denote an instance of the com.sun.star.sdb.RowSet, or an instance obtained by calling com.sun.star.sdb.XResultSetAccess.createResultSet() on such a com.sun.star.sdb.RowSet. This becomes important in conjunction with the Selection property.
        
        For the interaction of this property with other data access relevant properties, see the com.sun.star.sdb.DataAccessDescriptor service.
        """
        ...

    @abstractproperty
    def SaveAsSingleFile(self) -> bool:
        """
        determines that the output of the mail merge is saved in one single file.
        
        This property is only evaluated for file output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def SaveFilter(self) -> str:
        """
        contains the name of the document filter to save the output file(s).
        
        This property is only evaluated for file output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def SendAsAttachment(self) -> bool:
        """
        determines that the created mail merge document is sent as attachment.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def SendAsHTML(self) -> bool:
        """
        determines that the created mail merge document is sent as body in HTML format.
        
        This property is only valid if the property \"SendAsAttachment\" is set to FALSE.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def SinglePrintJobs(self) -> bool:
        """
        determines whether single print jobs will be generated per output document.
        
        This property is only evaluated for printer output.
        """
        ...

    @abstractproperty
    def Subject(self) -> str:
        """
        contains the subject of the e-Mail message.
        
        This property is only evaluated for e-Mail output.
        
        **since**
        
            OOo 2.0
        """
        ...


__all__ = ['MailMerge']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.script.browse.browse_node import BrowseNode as BrowseNode
from ....lo.script.browse.browse_node_factory import BrowseNodeFactory as BrowseNodeFactory
from ....lo.script.browse.browse_node_factory_view_types import BrowseNodeFactoryViewTypes as BrowseNodeFactoryViewTypes
from ....lo.script.browse.browse_node_types import BrowseNodeTypes as BrowseNodeTypes
from ....lo.script.browse.x_browse_node import XBrowseNode as XBrowseNode
from ....lo.script.browse.x_browse_node_factory import XBrowseNodeFactory as XBrowseNodeFactory
from ....lo.script.browse.the_browse_node_factory import theBrowseNodeFactory as theBrowseNodeFactory



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import uno
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XFastTokenHandler(XInterface_8f010a43):
    """
    interface to translate XML strings to integer tokens.
    
    An instance of this interface can be registered at a XFastParser. It should be able to translate all XML names (element local names, attribute local names and constant attribute values) to integer tokens.
    
    A token value must be greater or equal to zero and less than FastToken.NAMESPACE. If a string identifier is not known to this instance, FastToken.DONTKNOW is returned.

    See Also:
        `API XFastTokenHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastTokenHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XFastTokenHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XFastTokenHandler'

    @abstractmethod
    def getTokenFromUTF8(self, Identifier: uno.ByteSequence) -> int:
        """
        returns an integer token for the given string
        """
        ...
    @abstractmethod
    def getUTF8Identifier(self, Token: int) -> uno.ByteSequence:
        """
        returns an identifier for the given integer token as a byte sequence encoded in UTF-8.
        """
        ...

__all__ = ['XFastTokenHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class BibliographyDataField(metaclass=UnoConstMeta, type_name="com.sun.star.text.BibliographyDataField", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.BibliographyDataField``"""
        pass

    class BibliographyDataFieldEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.BibliographyDataField", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.BibliographyDataField`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.text import BibliographyDataField as BibliographyDataField
    else:
        # keep document generators happy
        from ...lo.text.bibliography_data_field import BibliographyDataField as BibliographyDataField

    class BibliographyDataFieldEnum(IntEnum):
        """
        Enum of Const Class BibliographyDataField

        These values define parts of bibliographic data.
        
        They are used to create a bibliography in a text document.
        
        Depending on the type of the data some of the fields will usually be left empty.
        
        **since**
        
            LibreOffice 7.3
        """
        IDENTIFIER = BibliographyDataField.IDENTIFIER
        """
        This field contains a unique identifier for the bibliographic data.
        """
        BIBILIOGRAPHIC_TYPE = BibliographyDataField.BIBILIOGRAPHIC_TYPE
        """
        This field contains the type of the bibliographic reference.
        
        It is of the type BibliographyDataType.
        """
        ADDRESS = BibliographyDataField.ADDRESS
        """
        This field contains the address of the publisher.
        """
        ANNOTE = BibliographyDataField.ANNOTE
        """
        This field contains an annotation.
        """
        AUTHOR = BibliographyDataField.AUTHOR
        """
        This field contains the name(s) of the author(s)
        """
        BOOKTITLE = BibliographyDataField.BOOKTITLE
        """
        This field contains the title of the book.
        """
        CHAPTER = BibliographyDataField.CHAPTER
        """
        This field contains the name or number of the chapter.
        """
        EDITION = BibliographyDataField.EDITION
        """
        This field contains the number or name of the edition.
        """
        EDITOR = BibliographyDataField.EDITOR
        """
        This field contains the name(s) of the editor(s)
        """
        HOWPUBLISHED = BibliographyDataField.HOWPUBLISHED
        """
        This field contains a description of the type of the publishing.
        """
        INSTITUTION = BibliographyDataField.INSTITUTION
        """
        This field contains the name of the institution where the publishing was created.
        """
        JOURNAL = BibliographyDataField.JOURNAL
        """
        This field contains the name of the journal.
        """
        MONTH = BibliographyDataField.MONTH
        """
        This field contains number or name of the month of the publishing.
        """
        NOTE = BibliographyDataField.NOTE
        """
        This field contains a note.
        """
        NUMBER = BibliographyDataField.NUMBER
        """
        This field contains the number of the publishing.
        """
        ORGANIZATIONS = BibliographyDataField.ORGANIZATIONS
        """
        This field contains the name of the organizations where the publishing was created.
        """
        PAGES = BibliographyDataField.PAGES
        """
        This field contains the number(s) of the page(s) of the reference into a publishing.
        """
        PUBLISHER = BibliographyDataField.PUBLISHER
        """
        This field contains the name of the publisher.
        """
        SCHOOL = BibliographyDataField.SCHOOL
        """
        This field contains the name of the university or school where the publishing was created.
        """
        SERIES = BibliographyDataField.SERIES
        """
        This field contains the series of the publishing.
        """
        TITLE = BibliographyDataField.TITLE
        """
        This field contains the title of the publishing.
        """
        REPORT_TYPE = BibliographyDataField.REPORT_TYPE
        """
        This field contains a description of the type of the report.
        """
        VOLUME = BibliographyDataField.VOLUME
        """
        This field contains the volume of the publishing.
        """
        YEAR = BibliographyDataField.YEAR
        """
        This field contains the year when the publishing was created.
        """
        URL = BibliographyDataField.URL
        """
        This field contains URL of the publishing.
        """
        CUSTOM1 = BibliographyDataField.CUSTOM1
        """
        This field contains user defined data.
        """
        CUSTOM2 = BibliographyDataField.CUSTOM2
        """
        This field contains user defined data.
        """
        CUSTOM3 = BibliographyDataField.CUSTOM3
        """
        This field contains user defined data.
        """
        CUSTOM4 = BibliographyDataField.CUSTOM4
        """
        This field contains user defined data.
        """
        CUSTOM5 = BibliographyDataField.CUSTOM5
        """
        This field contains user defined data.
        """
        ISBN = BibliographyDataField.ISBN
        """
        This field contains the ISBN data of the publishing.
        """
        LOCAL_URL = BibliographyDataField.LOCAL_URL
        """
        This field contains a local copy of the publishing.
        
        **since**
        
            LibreOffice 7.3
        """

__all__ = ['BibliographyDataField', 'BibliographyDataFieldEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration.backend
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ComponentChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    This event is fired when a change becomes effective on the source of the event.

    See Also:
        `API ComponentChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1configuration_1_1backend_1_1ComponentChangeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.ComponentChangeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.configuration.backend.ComponentChangeEvent'
    """Literal Constant ``com.sun.star.configuration.backend.ComponentChangeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Component: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Component (str, optional): Component value.
        """

        if isinstance(Source, ComponentChangeEvent):
            oth: ComponentChangeEvent = Source
            self.Source = oth.Source
            self.Component = oth.Component
            return

        kargs = {
            "Source": Source,
            "Component": Component,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._component = kwargs["Component"]
        inst_keys = ('Component',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Component(self) -> str:
        """
        The name of the Component that changed.
        """
        return self._component

    @Component.setter
    def Component(self, value: str) -> None:
        self._component = value


__all__ = ['ComponentChangeEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class AffineMatrix2D(object):
    """
    Struct Class

    This structure defines a 2 by 3 affine matrix.
    
    The matrix defined by this structure constitutes an affine mapping of a point in 2D to another point in 2D. The last line of a complete 3 by 3 matrix is omitted, since it is implicitly assumed to be [0,0,1].
    
    An affine mapping, as performed by this matrix, can be written out as follows, where xs and ys are the source, and xd and yd the corresponding result coordinates:
    
    xd = m00*xs + m01*ys + m02; yd = m10*xs + m11*ys + m12;
    
    Thus, in common matrix language, with M being the AffineMatrix2D and vs=[xs,ys]^T, vd=[xd,yd]^T two 2D vectors, the affine transformation is written as vd=M*vs. Concatenation of transformations amounts to multiplication of matrices, i.e. a translation, given by T, followed by a rotation, given by R, is expressed as vd=R*(T*vs) in the above notation. Since matrix multiplication is associative, this can be shortened to vd=(R*T)*vs=M'*vs. Therefore, a set of consecutive transformations can be accumulated into a single AffineMatrix2D, by multiplying the current transformation with the additional transformation from the left.
    
    Due to this transformational approach, all geometry data types are points in abstract integer or real coordinate spaces, without any physical dimensions attached to them. This physical measurement units are typically only added when using these data types to render something onto a physical output device, like a screen or a printer, Then, the total transformation matrix and the device resolution determine the actual measurement unit.
    
    **since**
    
        OOo 2.0

    See Also:
        `API AffineMatrix2D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1AffineMatrix2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.geometry'
    __ooo_full_ns__: str = 'com.sun.star.geometry.AffineMatrix2D'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.geometry.AffineMatrix2D'
    """Literal Constant ``com.sun.star.geometry.AffineMatrix2D``"""

    def __init__(self, m00: typing.Optional[float] = 0.0, m01: typing.Optional[float] = 0.0, m02: typing.Optional[float] = 0.0, m10: typing.Optional[float] = 0.0, m11: typing.Optional[float] = 0.0, m12: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            m00 (float, optional): m00 value.
            m01 (float, optional): m01 value.
            m02 (float, optional): m02 value.
            m10 (float, optional): m10 value.
            m11 (float, optional): m11 value.
            m12 (float, optional): m12 value.
        """
        super().__init__()

        if isinstance(m00, AffineMatrix2D):
            oth: AffineMatrix2D = m00
            self.m00 = oth.m00
            self.m01 = oth.m01
            self.m02 = oth.m02
            self.m10 = oth.m10
            self.m11 = oth.m11
            self.m12 = oth.m12
            return

        kargs = {
            "m00": m00,
            "m01": m01,
            "m02": m02,
            "m10": m10,
            "m11": m11,
            "m12": m12,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._m00 = kwargs["m00"]
        self._m01 = kwargs["m01"]
        self._m02 = kwargs["m02"]
        self._m10 = kwargs["m10"]
        self._m11 = kwargs["m11"]
        self._m12 = kwargs["m12"]


    @property
    def m00(self) -> float:
        """
        The top, left matrix entry.
        """
        return self._m00

    @m00.setter
    def m00(self, value: float) -> None:
        self._m00 = value

    @property
    def m01(self) -> float:
        """
        The top, middle matrix entry.
        """
        return self._m01

    @m01.setter
    def m01(self, value: float) -> None:
        self._m01 = value

    @property
    def m02(self) -> float:
        """
        The top, right matrix entry.
        """
        return self._m02

    @m02.setter
    def m02(self, value: float) -> None:
        self._m02 = value

    @property
    def m10(self) -> float:
        """
        The bottom, left matrix entry.
        """
        return self._m10

    @m10.setter
    def m10(self, value: float) -> None:
        self._m10 = value

    @property
    def m11(self) -> float:
        """
        The bottom, middle matrix entry.
        """
        return self._m11

    @m11.setter
    def m11(self, value: float) -> None:
        self._m11 = value

    @property
    def m12(self) -> float:
        """
        The bottom, right matrix entry.
        """
        return self._m12

    @m12.setter
    def m12(self, value: float) -> None:
        self._m12 = value


__all__ = ['AffineMatrix2D']
